import { TmplAstElement, TmplAstNode } from "@angular/compiler";
/**
 * Traverses the given tree of nodes and runs the given callbacks for each Element node encountered.
 *
 * Note that updates to the start tags of html element should be done in the postorder callback,
 * and updates to the end tags of html elements should be done in the preorder callback to avoid
 * issues with line collisions.
 *
 * @param nodes The nodes of the ast from a parsed template.
 * @param preorderCallback A function that gets run for each Element node in a preorder traversal.
 * @param postorderCallback A function that gets run for each Element node in a postorder traversal.
 */
export declare function visitElements(nodes: TmplAstNode[], preorderCallback?: (node: TmplAstElement) => void, postorderCallback?: (node: TmplAstElement) => void): void;
/**
 * Replaces the start tag of the given Element node inside of the html document with a new tag name.
 *
 * @param html The full html document.
 * @param node The Element node to be updated.
 * @param tag A new tag name.
 * @returns an updated html document.
 */
export declare function replaceStartTag(html: string, node: TmplAstElement, tag: string): string;
/**
 * Replaces the end tag of the given Element node inside of the html document with a new tag name.
 *
 * @param html The full html document.
 * @param node The Element node to be updated.
 * @param tag A new tag name.
 * @returns an updated html document.
 */
export declare function replaceEndTag(html: string, node: TmplAstElement, tag: string): string;
/**
 * Appends an attribute to the given node of the template html.
 *
 * @param html The template html to be updated.
 * @param node The node to be updated.
 * @param name The name of the attribute.
 * @param update The function that determines how to update the value.
 * @returns The updated template html.
 */
export declare function updateAttribute(html: string, node: TmplAstElement, name: string, update: (old: string | null) => string | null): string;
